==> jc-1.4.0.tar.gz: soot/jimple/JasminClass__242.h <==
// class soot.jimple.JasminClass$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class d2a789c0755bb52f soot_jimple_JasminClass__242

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_JasminClass__242_H_
#define _JC_soot_jimple_JasminClass__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_JasminClass$object;
struct _jc_soot_jimple_JasminClass__242$object;
struct _jc_soot_jimple_StaticFieldRef$object;

// Typedefs
typedef struct _jc_soot_jimple_JasminClass__242$sub_refs	_jc_soot_jimple_JasminClass__242$sub_refs;
typedef struct _jc_soot_jimple_JasminClass__242$sub_nonrefs	_jc_soot_jimple_JasminClass__242$sub_nonrefs;
typedef struct _jc_soot_jimple_JasminClass__242$refs	_jc_soot_jimple_JasminClass__242$refs;
typedef struct _jc_soot_jimple_JasminClass__242$nonrefs	_jc_soot_jimple_JasminClass__242$nonrefs;
typedef struct _jc_soot_jimple_JasminClass__242$object	_jc_soot_jimple_JasminClass__242$object;

typedef const struct _jc_soot_jimple_JasminClass__242$vmethods	_jc_soot_jimple_JasminClass__242$vmethods;
typedef const struct _jc_soot_jimple_JasminClass__242$vtable	_jc_soot_jimple_JasminClass__242$vtable;
typedef const struct _jc_soot_jimple_JasminClass__242$vtype	_jc_soot_jimple_JasminClass__242$vtype;

// Constructors
extern void _jc_soot_jimple_JasminClass__242$method$_init$18996610e974bfa6(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_JasminClass$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_JasminClass__242$method$caseArrayRef$21785baef489451a(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__242$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__242$method$caseLocal$22d2ce69207555ad(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__242$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
extern void _jc_soot_jimple_JasminClass__242$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseArrayRef$21785baef489451a;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseLocal$22d2ce69207555ad;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$defaultCase$707752a9a764fffd;

// Static methods
extern struct _jc_soot_jimple_JasminClass$object *_jc_soot_jimple_JasminClass__242$method$access__24000$26746db9a8b1e007(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *);
extern struct _jc_object *_jc_soot_jimple_JasminClass__242$method$access__24100$f2218f7ec0e3b9d1(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *);

// Virtual methods structure
struct _jc_soot_jimple_JasminClass__242$vmethods {
	void	(*caseArrayRef$21785baef489451a)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
	void	(*caseLocal$22d2ce69207555ad)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_JasminClass__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_JasminClass__242$vmethods	soot_jimple_JasminClass__242;
};

// Vtype
struct _jc_soot_jimple_JasminClass__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_JasminClass__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__242$sub_refs {
	struct _jc_object	*val__24rvalue;
	struct _jc_soot_jimple_JasminClass$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JasminClass__242$refs {
    _jc_soot_jimple_JasminClass__242$sub_refs	soot_jimple_JasminClass__242;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JasminClass__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_JasminClass__242$sub_nonrefs	soot_jimple_JasminClass__242;
};

// Object instance structure
struct _jc_soot_jimple_JasminClass__242$object {
	_jc_soot_jimple_JasminClass__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JasminClass__242$vtype	*vtype;
	_jc_soot_jimple_JasminClass__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JasminClass__242$vtype _jc_soot_jimple_JasminClass__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JasminClass__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JasminClass__242$class_object;

#endif	/* _JC_soot_jimple_JasminClass__242_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/JasminClass__242.h <==
// class soot.jimple.JasminClass$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class d2a789c0755bb52f soot_jimple_JasminClass__242

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_JasminClass__242_H_
#define _JC_soot_jimple_JasminClass__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_JasminClass$object;
struct _jc_soot_jimple_JasminClass__242$object;
struct _jc_soot_jimple_StaticFieldRef$object;

// Typedefs
typedef struct _jc_soot_jimple_JasminClass__242$sub_refs	_jc_soot_jimple_JasminClass__242$sub_refs;
typedef struct _jc_soot_jimple_JasminClass__242$sub_nonrefs	_jc_soot_jimple_JasminClass__242$sub_nonrefs;
typedef struct _jc_soot_jimple_JasminClass__242$refs	_jc_soot_jimple_JasminClass__242$refs;
typedef struct _jc_soot_jimple_JasminClass__242$nonrefs	_jc_soot_jimple_JasminClass__242$nonrefs;
typedef struct _jc_soot_jimple_JasminClass__242$object	_jc_soot_jimple_JasminClass__242$object;

typedef const struct _jc_soot_jimple_JasminClass__242$vmethods	_jc_soot_jimple_JasminClass__242$vmethods;
typedef const struct _jc_soot_jimple_JasminClass__242$vtable	_jc_soot_jimple_JasminClass__242$vtable;
typedef const struct _jc_soot_jimple_JasminClass__242$vtype	_jc_soot_jimple_JasminClass__242$vtype;

// Constructors
extern void _jc_soot_jimple_JasminClass__242$method$_init$18996610e974bfa6(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_JasminClass$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_JasminClass__242$method$caseArrayRef$21785baef489451a(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__242$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__242$method$caseLocal$22d2ce69207555ad(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__242$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__242$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseArrayRef$21785baef489451a;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseLocal$22d2ce69207555ad;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_soot_jimple_JasminClass__242$method_info$defaultCase$707752a9a764fffd;

// Static methods
extern struct _jc_soot_jimple_JasminClass$object *_jc_soot_jimple_JasminClass__242$method$access__24000$26746db9a8b1e007(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_JasminClass__242$method$access__24100$f2218f7ec0e3b9d1(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_JasminClass__242$vmethods {
	void	(*caseArrayRef$21785baef489451a)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseLocal$22d2ce69207555ad)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_JasminClass__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_JasminClass__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_JasminClass__242$vmethods	soot_jimple_JasminClass__242;
};

// Vtype
struct _jc_soot_jimple_JasminClass__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_JasminClass__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__242$sub_refs {
	struct _jc_object	*val__24rvalue;
	struct _jc_soot_jimple_JasminClass$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JasminClass__242$refs {
    _jc_soot_jimple_JasminClass__242$sub_refs	soot_jimple_JasminClass__242;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JasminClass__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_JasminClass__242$sub_nonrefs	soot_jimple_JasminClass__242;
};

// Object instance structure
struct _jc_soot_jimple_JasminClass__242$object {
	_jc_soot_jimple_JasminClass__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JasminClass__242$vtype	*vtype;
	_jc_soot_jimple_JasminClass__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JasminClass__242$vtype _jc_soot_jimple_JasminClass__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JasminClass__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JasminClass__242$class_object;

#endif	/* _JC_soot_jimple_JasminClass__242_H_ */
